@@ -1,5 +1,5 @@
 /* Copyright (C) 2004 Bart 'plors' Hakvoort
- * Copyright (C) 2008, 2009, 2010 Curtis Gedak
+ * Copyright (C) 2008, 2009, 2010, 2011 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -277,27 +277,40 @@ int Utils::execute_command( const Glib::ustring & command,
 
 	try
 	{
+		std::vector<std::string>argv;
+		argv .push_back( "sh" ) ;
+		argv .push_back( "-c" ) ;
+		argv .push_back( command ) ;
+
 		if ( use_C_locale )
 		{
-			std::vector<std::string> envp, argv;
+			//Spawn command using the C language environment
+			std::vector<std::string> envp ;
 			envp .push_back( "LC_ALL=C" ) ;
 			envp .push_back( "PATH=" + Glib::getenv( "PATH" ) ) ;
 
-			argv .push_back( "sh" ) ;
-			argv .push_back( "-c" ) ;
-			argv .push_back( command ) ;
-
-			Glib::spawn_sync( ".",
-					  argv,
-					  envp,
-					  Glib::SPAWN_SEARCH_PATH,
-					  sigc::slot<void>(),
-					  &std_out,
-					  &std_error,
-					  &exit_status ) ;
+			Glib::spawn_sync( "."
+			                , argv
+			                , envp
+			                , Glib::SPAWN_SEARCH_PATH
+			                , sigc::slot<void>()
+			                , &std_out
+			                , &std_error
+			                , &exit_status
+			                ) ;
 		}
 		else
-			Glib::spawn_command_line_sync( "sh -c '" + command + "'", &std_out, &std_error, &exit_status ) ;
+		{
+			//Spawn command inheriting the parent's environment
+			Glib::spawn_sync( "."
+			                , argv
+			                , Glib::SPAWN_SEARCH_PATH
+			                , sigc::slot<void>()
+			                , &std_out
+			                , &std_error
+			                , &exit_status
+			                ) ;
+		}
 	}
 	catch ( Glib::Exception & e )
 	{
@@ -409,34 +422,33 @@ Glib::ustring Utils::trim( const Glib::ustring & src, const Glib::ustring & c /*
 
 Glib::ustring Utils::cleanup_cursor( const Glib::ustring & text )
 {
-	//Clean up text for commands that use cursoring to display progress.
-	Glib::ustring str = text;
-	//remove backspace '\b' and delete previous character.  Used in mke2fs output.
-	for ( unsigned int index = str .find( "\b" ) ; index < str .length() ; index = str .find( "\b" ) ) {
-		if ( index > 0 )
-			str .erase( index - 1, 2 ) ;
-		else
-			str .erase( index, 1 ) ;
+	std::istringstream in(text);
+	std::ostringstream out;
+	char ch;
+	std::streampos startofline = out.tellp();
+
+	while (in.get(ch))
+	{
+		switch(ch)
+		{
+			case '\r':
+				if ('\n' != in.peek()) // for windows CRLF
+					out.seekp(startofline);
+				else
+					out.put(ch);
+				break;
+			case '\b':
+				if (out.tellp() > startofline)
+					out.seekp(out.tellp()-1ll);
+				break;
+			default:
+				out.put(ch);
+		}
+		if (ch == '\n')
+		 	startofline = out.tellp();
 	}
 
-	//Remove carriage return and line up to previous line feed.  Used in ntfsclone output.
-	//NOTE:  Normal linux line end is line feed.  DOS uses CR + LF.
-	for ( unsigned int index1 = str .find( "\r") ; index1 < str .length() ; index1 = str .find( "\r" ) )
-	{
-		//Only process if next character is not a LF.
-		if ( str .at(index1 + 1) != '\n')
-		{
-			//find point to start erase from.
-			unsigned int index2 = str .rfind( "\n", index1 ) ;
-			//find end point to erase up to.
-			unsigned int index3 = str .find( "\n", index1 ) ;
-			unsigned int index4 = str .rfind( "\r", index3 ) ;
-			//perform erase if indices are valid
-			if ( ( index2 <= index1 ) && ( index4 > index2 ) && ( index4 < str .length() ) )
-				str .erase( index2 + 1, index4 - index2 ) ;
-		}
-	}
-	return str;
+	return out.str();
 }
 
 Glib::ustring Utils::get_lang()
@@ -481,5 +493,15 @@ void Utils::tokenize( const Glib::ustring& str,
 	}
 }
 
+// Converts a Glib::ustring into a int
+int Utils::convert_to_int(const Glib::ustring & src)
+{
+	int ret_val;
+	std::istringstream stream(src);
+	stream >> ret_val;
+
+	return ret_val;
+}
+
 
 } //GParted..
