@@ -1,5 +1,5 @@
 /* Copyright (C) 2004 Bart
- * Copyright (C) 2008, 2009, 2010 Curtis Gedak
+ * Copyright (C) 2008, 2009, 2010, 2011 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 #include "../include/Dialog_Progress.h"
 #include "../include/DialogFeatures.h" 
 #include "../include/Dialog_Disklabel.h"
+#include "../include/Dialog_Rescue_Data.h"
 #include "../include/Dialog_Partition_Resize_Move.h"
 #include "../include/Dialog_Partition_Copy.h"
 #include "../include/Dialog_Partition_New.h"
@@ -183,6 +184,10 @@ void Win_GParted::init_menubar()
 	menu = manage( new Gtk::Menu() ) ;
 	menu ->items() .push_back( Gtk::Menu_Helpers::MenuElem( Glib::ustring( _("_Create Partition Table") ) + "...",
 								sigc::mem_fun(*this, &Win_GParted::activate_disklabel) ) );
+
+	menu ->items() .push_back( Gtk::Menu_Helpers::MenuElem( Glib::ustring( _("_Attempt Data Rescue") ) + "...",
+								sigc::mem_fun(*this, &Win_GParted::activate_attempt_rescue_data) ) );
+
 	menubar_main .items() .push_back( Gtk::Menu_Helpers::MenuElem( _("_Device"), *menu ) );
 
 	//partition
@@ -689,6 +694,16 @@ void Win_GParted::Add_Operation( Operation * operation, int index )
 			
 			if ( operations .size() == 1 ) //first operation, open operationslist
 				open_operationslist() ;
+
+			//FIXME:  A slight flicker may be introduced by this extra display refresh.
+			//An extra display refresh seems to prevent the disk area visual disk from
+			//  disappearing when enough operations are added to require a scrollbar
+			//  (about 4 operations with default window size).
+			//  Note that commenting out the code to
+			//  "//make scrollwindow focus on the last operation in the list"
+			//  in HBoxOperations::load_operations() prevents this problem from occurring as well.
+			//  See also Win_GParted::activate_undo().
+			drawingarea_visualdisk .queue_draw() ;
 		}
 		else
 		{
@@ -1236,6 +1251,13 @@ void Win_GParted::show_help_dialog( const Glib::ustring & filename /* E.g., gpar
 	Glib::ustring command = "gnome-open " + uri ;
 	gdk_spawn_command_line_on_screen( gscreen, command .c_str(), &error ) ;
 #endif
+	if ( error != NULL )
+	{
+		//Try opening yelp application directly
+		g_clear_error( &error ) ;  //Clear error from trying to open gparted help manual above (gtk_show_uri or gnome-open).
+		Glib::ustring command = "yelp " + uri ;
+		gdk_spawn_command_line_on_screen( gscreen, command .c_str(), &error ) ;
+	}
 
 	if ( error != NULL )
 	{
@@ -1285,7 +1307,7 @@ void Win_GParted::menu_help_about()
 	dialog .set_logo_icon_name( "gparted" ) ;
 	dialog .set_version( VERSION ) ;
 	dialog .set_comments( _( "GNOME Partition Editor" ) ) ;
-	dialog .set_copyright( "Copyright © 2004-2006 Bart Hakvoort\nCopyright © 2008-2010 Curtis Gedak" ) ;
+	dialog .set_copyright( "Copyright © 2004-2006 Bart Hakvoort\nCopyright © 2008-2011 Curtis Gedak" ) ;
 
 	//authors
 	strings .push_back( "Bart Hakvoort <gparted@users.sf.net>" ) ;
@@ -1823,7 +1845,15 @@ void Win_GParted::thread_toggle_swap( bool * succes, Glib::ustring * error )
 	pulse = false ;
 }
 
-void Win_GParted::toggle_swap_mount_state() 
+// Runs gpart in a thread
+void Win_GParted::thread_guess_partition_table()
+{
+	this->gpart_output="";
+	this->gparted_core.guess_partition_table(devices[ current_device ], this->gpart_output);
+	pulse=false;
+}
+
+void Win_GParted::toggle_swap_mount_state()
 {
 	int operation_count = partition_in_operation_queue_count( selected_partition ) ;
 	if ( operation_count > 0 )
@@ -2061,7 +2091,77 @@ void Win_GParted::activate_disklabel()
 		menu_gparted_refresh_devices() ;
 	}
 }
-	
+
+//Runs when the Device->Attempt Rescue Data is clicked
+void Win_GParted::activate_attempt_rescue_data()
+{
+	if(Glib::find_program_in_path( "gpart" ) .empty()) //Gpart must be installed to continue
+	{
+		Gtk::MessageDialog errorDialog(*this, "", true, Gtk::MESSAGE_ERROR, Gtk::BUTTONS_OK, true);
+		errorDialog.set_message(_("Command gpart was not found"));
+		errorDialog.set_secondary_text(_("This feature uses gpart. Please install gpart and try again."));
+
+		errorDialog.run();
+
+		return;
+	}
+
+	//Dialog information
+	Glib::ustring sec_text = _( "A full disk scan is needed to find file systems." ) ;
+	sec_text += "\n" ;
+	sec_text +=_("The scan might take a very long time.");
+	sec_text += "\n" ;
+	sec_text += _("After the scan you can mount any discovered file systems and copy the data to other media.") ;
+	sec_text += "\n" ;
+	sec_text += _("Do you want to continue?");
+
+	Gtk::MessageDialog messageDialog(*this, "", true, Gtk::MESSAGE_WARNING, Gtk::BUTTONS_OK_CANCEL, true);
+	/*TO TRANSLATORS: looks like	Search for file systems on /deb/sdb */
+	messageDialog.set_message(String::ucompose(_("Search for file systems on %1"), devices[ current_device ] .get_path()));
+	messageDialog.set_secondary_text(sec_text);
+
+	if(messageDialog.run()!=Gtk::RESPONSE_OK)
+	{
+		return;
+	}
+
+	messageDialog.hide();
+
+	pulse=true;
+	this->thread = Glib::Thread::create( sigc::mem_fun( *this, &Win_GParted::thread_guess_partition_table ), true ) ;
+
+	/*TO TRANSLATORS: looks like	Searching for file systems on /deb/sdb */
+	show_pulsebar(String::ucompose( _("Searching for file systems on %1"), devices[ current_device ] .get_path()));
+
+	Dialog_Rescue_Data dialog;
+	dialog .set_transient_for( *this );
+
+	//Reads the output of gpart
+	dialog.init_partitions(&devices[ current_device ], this->gpart_output);
+
+	if(dialog.get_partitions().size()==0) //No partitions found
+	{
+		//Dialog information
+		Gtk::MessageDialog errorDialog(*this, "", true, Gtk::MESSAGE_ERROR, Gtk::BUTTONS_OK, true);
+		
+		/*TO TRANSLATORS: looks like	No file systems found on /deb/sdb */
+		errorDialog.set_message(String::ucompose(_("No file systems found on %1"), devices[ current_device ] .get_path()));
+		errorDialog.set_secondary_text(_("The disk scan by gpart did not find any recognizable file systems on this disk."));
+
+		errorDialog.run();
+		return;
+	}
+
+	dialog.run();
+	dialog.hide();
+
+	Glib::ustring commandUmount= "umount /tmp/gparted-roview*";
+
+	Utils::execute_command(commandUmount);
+
+	menu_gparted_refresh_devices() ;
+}
+
 void Win_GParted::activate_manage_flags() 
 {
 	get_window() ->set_cursor( Gdk::Cursor( Gdk::WATCH ) ) ;
@@ -2136,6 +2236,13 @@ void Win_GParted::activate_undo()
 	
 	if ( ! operations .size() )
 		close_operationslist() ;
+
+	//FIXME:  A slight flicker may be introduced by this extra display refresh.
+	//An extra display refresh seems to prevent the disk area visual disk from
+	//  disappearing when there enough operations to require a scrollbar
+	//  (about 4+ operations with default window size) and a user clicks on undo.
+	//  See also Win_GParted::Add_operation().
+	drawingarea_visualdisk .queue_draw() ;
 }
 
 void Win_GParted::remove_operation( int index, bool remove_all ) 
