@@ -121,6 +121,14 @@ bool ext2::resize( const Partition & partition_new, OperationDetail & operationd
 	return ! execute_command( str_temp, operationdetail ) ;
 }
 
+bool ext2::move( const Partition & partition_new
+               , const Partition & partition_old
+               , OperationDetail & operationdetail
+               )
+{
+	return true ;
+}
+
 bool ext2::copy( const Glib::ustring & src_part_path, 
 		 const Glib::ustring & dest_part_path,
 		 OperationDetail & operationdetail )
