@@ -161,6 +161,14 @@ bool fat16::resize( const Partition & partition_new, OperationDetail & operation
 	return true ;
 }
 
+bool fat16::move( const Partition & partition_new
+                , const Partition & partition_old
+                , OperationDetail & operationdetail
+                )
+{
+	return true ;
+}
+
 bool fat16::copy( const Glib::ustring & src_part_path,
 		  const Glib::ustring & dest_part_path,
 		  OperationDetail & operationdetail )
